/*
 * Copyright (c) 2021 Huawei Device Co., Ltd.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef UNIT_DATETIME_TEST_H_
#define UNIT_DATETIME_TEST_H_

#include <string>
#include <vector>
#include <algorithm>
#include "locale_info.h"
#include "date_time_format.h"

namespace testing {
using namespace OHOS;
using namespace I18N;
using ::std::string;
using ::std::vector;
vector<LocaleInfo> g_locales = {
    LocaleInfo("ar", "", ""),       LocaleInfo("ar", "AE"),         LocaleInfo("ar", "EG"),
    LocaleInfo("as", "Latn", "IN"), LocaleInfo("de", "DE"),         LocaleInfo("en", "", ""),
    LocaleInfo("en", "GB"),         LocaleInfo("en", "Qaag", ""),   LocaleInfo("en", "US"),
    LocaleInfo("es", "ES"),         LocaleInfo("es", "US"),         LocaleInfo("fr", "FR"),
    LocaleInfo("it", "IT"),         LocaleInfo("ka", "GE"),         LocaleInfo("mai", "Deva", ""),
    LocaleInfo("my", "MM"),         LocaleInfo("pa", "Guru", ""),   LocaleInfo("pt", "BR"),
    LocaleInfo("pt", "PT"),         LocaleInfo("sr", "Cyrl", ""),   LocaleInfo("th", "TH"),
    LocaleInfo("zh", "", ""),       LocaleInfo("zh", "Hans", "CN"), LocaleInfo("zh", "Hans", "HK"),
    LocaleInfo("zh", "Hans", "MO"), LocaleInfo("zh", "Hant", "TW")
};


string g_dataTimeFormatPositive[][17] = {
    { "٤:٤٥:٠٠ ص", "٠٤:٤٥:٠٠", "٤:٤٥:٠٠ ص", "٤:٤٥ ص", "٠٤:٤٥", "٤:٤٥ ص", "الأربعاء، ٧ يناير",
      "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "٤:٤٥:٠٠ ص", "٠٤:٤٥:٠٠", "٤:٤٥:٠٠ ص", "٤:٤٥ ص", "٠٤:٤٥", "٤:٤٥ ص", "الأربعاء، ٧ يناير",
      "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "٤:٤٥:٠٠ ص", "٠٤:٤٥:٠٠", "٤:٤٥:٠٠ ص", "٤:٤٥ ص", "٠٤:٤٥", "٤:٤٥ ص",
      "الأربعاء، ٧ يناير", "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "পূৰ্বাহ্ণ ৪:৪৫:০০", "০৪:৪৫:০০", "পূৰ্বাহ্ণ ৪:৪৫:০০", "পূৰ্বাহ্ণ ৪:৪৫", "০৪:৪৫", "পূৰ্বাহ্ণ ৪:৪৫",
      "বুধ, ৭ জানু", "৭ জানু", "বুধ, ৭ জানু ১৯৭০", "বুধ, ৭ জানুৱাৰী, ১৯৭০", "বুধবাৰ, ০৭-০১-১৯৭০",
      "বুধ, ০৭-০১-১৯৭০", "বুধবাৰ, ৭ জানু, ১৯৭০", "৭ জানুৱাৰী, ১৯৭০", "বুধবাৰ, ৭ জানুৱাৰী, ১৯৭০",
      "০৭-০১-১৯৭০", "৭-১-১৯৭০" },
    { "4:45:00 AM", "04:45:00", "04:45:00", "4:45 AM", "04:45", "04:45", "Mi., 7. Jan.", "7. Jan.",
      "Mi., 7. Jan. 1970", "Mi., 7. Januar 1970", "Mittwoch, 7.1.1970", "Mi., 7.1.1970",
      "Mittwoch, 7. Jan. 1970", "7. Januar 1970", "Mittwoch, 7. Januar 1970", "07.01.1970", "07.01.70" },
    { "4:45:00 AM", "04:45:00", "4:45:00 AM", "4:45 AM", "04:45", "4:45 AM", "Wed, Jan 7",
      "Jan 7", "Wed, Jan 7, 1970", "Wed, January 7, 1970", "Wednesday, 1/7/1970", "Wed, 1/7/1970",
      "Wednesday, Jan 7, 1970", "January 7, 1970", "Wednesday, January 7, 1970", "Jan 7, 1970", "1/7/70" },
    { "4:45:00 am", "04:45:00", "04:45:00", "4:45 am", "04:45", "04:45", "Wed, 7 Jan", "7 Jan",
      "Wed, 7 Jan 1970", "Wed, 7 January 1970", "Wednesday, 07/01/1970", "Wed, 07/01/1970",
      "Wednesday, 7 Jan 1970", "7 January 1970", "Wednesday, 7 January 1970", "7 Jan 1970", "07/01/1970" },
    { "4:45:00 am", "04:45:00", "04:45:00", "4:45 am", "04:45", "04:45", "Wed, 7 Jan", "7 Jan",
      "Wed, 7 Jan 1970", "Wed, 7 January 1970", "Wednesday, 07/01/1970", "Wed, 07/01/1970",
      "Wednesday, 7 Jan 1970", "7 January 1970", "Wednesday, 7 January 1970", "7 Jan 1970", "07/01/1970" },
    { "4:45:00 AM", "04:45:00", "4:45:00 AM", "4:45 AM", "04:45", "4:45 AM", "Wed, Jan 7",
      "Jan 7", "Wed, Jan 7, 1970", "Wed, January 7, 1970", "Wednesday, 1/7/1970", "Wed, 1/7/1970",
      "Wednesday, Jan 7, 1970", "January 7, 1970", "Wednesday, January 7, 1970", "Jan 7, 1970", "1/7/70" },
    { "4:45:00 a. m.", "4:45:00", "4:45:00", "4:45 a. m.", "4:45", "4:45", "mié., 7 ene.",
      "7 ene.", "mié., 7 ene. 1970", "mié., 7 de enero de 1970", "miércoles, 7/1/1970",
      "mié., 7/1/1970", "miércoles, 7 de ene. de 1970", "7 de enero de 1970", "miércoles, 7 de enero de 1970",
      "7 ene. 1970", "7/1/70" },
    { "4:45:00 a. m.", "04:45:00", "4:45:00 a. m.", "4:45 a. m.", "04:45", "4:45 a. m.",
      "mié., 7 de ene.", "7 ene.", "mié., 7 de enero de 1970", "mié., 7 de enero de 1970",
      "miércoles, 7/1/1970", "mié., 7/1/1970", "miércoles, 7 de ene. de 1970", "7 de enero de 1970",
      "miércoles, 7 de enero de 1970", "7 ene. 1970", "7/1/1970" },
    { "4:45:00 AM", "04:45:00", "04:45:00", "4:45 AM", "04:45", "04:45", "mer. 7 janv.",
      "7 janv.", "mer. 7 janv. 1970", "mer. 7 janvier 1970", "mercredi 07/01/1970",
      "mer. 07/01/1970", "mercredi 7 janv. 1970", "7 janvier 1970", "mercredi 7 janvier 1970",
      "7 janv. 1970", "07/01/1970" },
    { "4:45:00 AM", "04:45:00", "04:45:00", "4:45 AM", "04:45", "04:45", "mer 7 gen", "7 gen",
      "mer 7 gen 1970", "mer 7 gennaio 1970", "mercoledì 7/1/1970", "mer 7/1/1970",
      "mercoledì 7 gen 1970", "7 gennaio 1970", "mercoledì 7 gennaio 1970", "7 gen 1970", "07/01/70" },
    { "4:45:00 AM", "04:45:00", "04:45:00", "4:45 AM", "04:45", "04:45", "ოთხ, 7 იან", "7 იან",
      "ოთხ, 7 იან, 1970", "ოთხ, 7 იანვარი, 1970", "ოთხშაბათი, 7.1.1970", "ოთხ, 7.1.1970",
      "ოთხშაბათი, 7 იან, 1970", "7 იანვარი, 1970", "ოთხშაბათი, 7 იანვარი, 1970", "7 იან, 1970", "07.01.70" },
    { "4:45:00 AM", "04:45:00", "4:45:00 AM", "4:45 AM", "04:45", "4:45 AM", "बुध, 7 जन",
      "7 जन", "बुध, 7 जन 1970", "बुध, 7 जनवरी 1970", "बुधवार, 7/1/1970", "बुध, 7/1/1970",
      "बुधवार, 7 जन 1970", "7 जनवरी 1970", "बुधवार, 7 जनवरी 1970", "7 जन 1970", "7/1/1970" },
    { "၄:၄၅:၀၀ နံနက်", "၀၄:၄၅:၀၀", "၀၄:၄၅:၀၀", "၄:၄၅ နံနက်", "၀၄:၄၅", "၀၄:၄၅", "ဗုဒ္ဓဟူးနေ့၊ ဇန်နဝါရီလ ၇ ရက်",
      "ဇန်နဝါရီလ ၇ ရက်", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀/၀၁/၀၇", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀/၀၁/၀၇", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "၇၀/၀၁/၀၇" },
    { "4:45:00 ਪੂ.ਦੁ.", "04:45:00", "4:45:00 ਪੂ.ਦੁ.", "4:45 ਪੂ.ਦੁ.", "04:45", "4:45 ਪੂ.ਦੁ.", "ਬੁੱਧ, 7 ਜਨ",
      "7 ਜਨ", "ਬੁੱਧ, 7 ਜਨ 1970", "ਬੁੱਧ, 7 ਜਨਵਰੀ 1970", "ਬੁੱਧਵਾਰ, 7/1/1970", "ਬੁੱਧ, 7/1/1970", "ਬੁੱਧਵਾਰ, 7 ਜਨ 1970",
      "7 ਜਨਵਰੀ 1970", "ਬੁੱਧਵਾਰ, 7 ਜਨਵਰੀ 1970", "7 ਜਨ 1970", "7/1/70" },
    { "4:45:00 AM", "04:45:00", "04:45:00", "4:45 AM", "04:45", "04:45", "qua, 7 de jan", "7 de jan",
      "qua, 7 de jan de 1970", "qua, 7 de janeiro de 1970", "quarta-feira, 07/01/1970", "qua, 07/01/1970",
      "quarta-feira, 7 de jan de 1970", "7 de janeiro de 1970", "quarta-feira, 7 de janeiro de 1970",
      "7 de jan de 1970", "07/01/1970" },
    { "4:45:00 a.m.", "04:45:00", "04:45:00", "4:45 a.m.", "04:45", "04:45", "qua, 7/01", "7 de jan",
      "qua, 7 de jan de 1970", "qua, 7 de janeiro de 1970", "quarta-feira, 07/01/1970", "qua, 07/01/1970",
      "quarta-feira, 7 de jan de 1970", "7 de janeiro de 1970", "quarta-feira, 7 de janeiro de 1970",
      "07/01/1970", "07/01/70" },
    { "4:45:00 пре подне", "04:45:00", "04:45:00", "4:45 пре подне", "04:45", "04:45", "сре 7. јан",
      "7. јан", "сре, 7. јан 1970.", "сре, 7. јануар 1970.", "среда, 7.1.1970.", "сре, 7.1.1970.",
      "среда, 7. јан 1970.", "7. јануар 1970.", "среда, 07. јануар 1970.", "07.01.1970.", "7.1.70." },
    { "4:45:00 ก่อนเที่ยง", "04:45:00", "04:45:00", "4:45 ก่อนเที่ยง", "04:45", "04:45", "พ. 7 ม.ค.",
      "7 ม.ค.", "พ. 7 ม.ค. 1970", "พ. 7 มกราคม  1970", "วันพุธ 7/1/1970", "พ. 7/1/1970",
      "วันพุธที่ 7 ม.ค. 1970", "7 มกราคม  1970", "วันพุธที่ 7 มกราคม  1970", "7 ม.ค. 1970", "7/1/70" },
    { "上午4:45:00", "04:45:00", "上午4:45:00", "上午4:45", "04:45", "上午4:45", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970/1/7周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "1970/1/7" },
    { "上午4:45:00", "04:45:00", "上午4:45:00", "上午4:45", "04:45", "上午4:45", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970/1/7周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "1970/1/7" },
    { "上午4:45:00", "04:45:00", "上午4:45:00", "上午4:45", "04:45", "上午4:45", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "7/1/1970（周三）",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "7/1/70" },
    { "上午4:45:00", "04:45:00", "上午4:45:00", "上午4:45", "04:45", "上午4:45", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970年1月7日，周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "7/1/70" },
    { "上午4:45:00", "04:45:00", "04:45:00", "上午4:45", "04:45", "04:45", "1月7日 週三",
      "1月7日", "1970年1月7日 週三", "1970年1月7日 週三", "1970年1月7日 星期三", "1970/1/7（週三）",
      "1970年1月7日 星期三", "1970年1月7日", "1970年1月7日 星期三", "1970年1月7日", "1970/1/7" }
};

string g_dateTimeFormat[][17] = {
    { "٣:٠٠:٠٠ ص", "٠٣:٠٠:٠٠", "٣:٠٠:٠٠ ص", "٣:٠٠ ص", "٠٣:٠٠", "٣:٠٠ ص",
      "الأربعاء، ٧ يناير", "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "٣:٠٠:٠٠ ص", "٠٣:٠٠:٠٠", "٣:٠٠:٠٠ ص", "٣:٠٠ ص", "٠٣:٠٠", "٣:٠٠ ص",
      "الأربعاء، ٧ يناير", "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "٣:٠٠:٠٠ ص", "٠٣:٠٠:٠٠", "٣:٠٠:٠٠ ص", "٣:٠٠ ص", "٠٣:٠٠", "٣:٠٠ ص",
      "الأربعاء، ٧ يناير", "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "পূৰ্বাহ্ণ ৩:০০:০০", "০৩:০০:০০", "পূৰ্বাহ্ণ ৩:০০:০০", "পূৰ্বাহ্ণ ৩:০০", "০৩:০০", "পূৰ্বাহ্ণ ৩:০০",
      "বুধ, ৭ জানু", "৭ জানু", "বুধ, ৭ জানু ১৯৭০", "বুধ, ৭ জানুৱাৰী, ১৯৭০", "বুধবাৰ, ০৭-০১-১৯৭০",
      "বুধ, ০৭-০১-১৯৭০", "বুধবাৰ, ৭ জানু, ১৯৭০", "৭ জানুৱাৰী, ১৯৭০", "বুধবাৰ, ৭ জানুৱাৰী, ১৯৭০",
      "০৭-০১-১৯৭০", "৭-১-১৯৭০" },
    { "3:00:00 AM", "03:00:00", "03:00:00", "3:00 AM", "03:00", "03:00", "Mi., 7. Jan.",
      "7. Jan.", "Mi., 7. Jan. 1970", "Mi., 7. Januar 1970", "Mittwoch, 7.1.1970",
      "Mi., 7.1.1970", "Mittwoch, 7. Jan. 1970", "7. Januar 1970", "Mittwoch, 7. Januar 1970",
      "07.01.1970", "07.01.70" },
    { "3:00:00 AM", "03:00:00", "3:00:00 AM", "3:00 AM", "03:00", "3:00 AM", "Wed, Jan 7",
      "Jan 7", "Wed, Jan 7, 1970", "Wed, January 7, 1970", "Wednesday, 1/7/1970", "Wed, 1/7/1970",
      "Wednesday, Jan 7, 1970", "January 7, 1970", "Wednesday, January 7, 1970", "Jan 7, 1970", "1/7/70" },
    { "3:00:00 am", "03:00:00", "03:00:00", "3:00 am", "03:00", "03:00", "Wed, 7 Jan", "7 Jan",
      "Wed, 7 Jan 1970", "Wed, 7 January 1970", "Wednesday, 07/01/1970", "Wed, 07/01/1970",
      "Wednesday, 7 Jan 1970", "7 January 1970", "Wednesday, 7 January 1970", "7 Jan 1970", "07/01/1970" },
    { "3:00:00 am", "03:00:00", "03:00:00", "3:00 am", "03:00", "03:00", "Wed, 7 Jan", "7 Jan",
      "Wed, 7 Jan 1970", "Wed, 7 January 1970", "Wednesday, 07/01/1970", "Wed, 07/01/1970",
      "Wednesday, 7 Jan 1970", "7 January 1970", "Wednesday, 7 January 1970", "7 Jan 1970", "07/01/1970" },
    { "3:00:00 AM", "03:00:00", "3:00:00 AM", "3:00 AM", "03:00", "3:00 AM", "Wed, Jan 7",
      "Jan 7", "Wed, Jan 7, 1970", "Wed, January 7, 1970", "Wednesday, 1/7/1970", "Wed, 1/7/1970",
      "Wednesday, Jan 7, 1970", "January 7, 1970", "Wednesday, January 7, 1970", "Jan 7, 1970", "1/7/70" },
    { "3:00:00 a. m.", "3:00:00", "3:00:00", "3:00 a. m.", "3:00", "3:00", "mié., 7 ene.",
      "7 ene.", "mié., 7 ene. 1970", "mié., 7 de enero de 1970", "miércoles, 7/1/1970",
      "mié., 7/1/1970", "miércoles, 7 de ene. de 1970", "7 de enero de 1970",
      "miércoles, 7 de enero de 1970", "7 ene. 1970", "7/1/70" },
    { "3:00:00 a. m.", "03:00:00", "3:00:00 a. m.", "3:00 a. m.", "03:00", "3:00 a. m.",
      "mié., 7 de ene.", "7 ene.", "mié., 7 de enero de 1970", "mié., 7 de enero de 1970",
      "miércoles, 7/1/1970", "mié., 7/1/1970", "miércoles, 7 de ene. de 1970", "7 de enero de 1970",
      "miércoles, 7 de enero de 1970", "7 ene. 1970", "7/1/1970" },
    { "3:00:00 AM", "03:00:00", "03:00:00", "3:00 AM", "03:00", "03:00", "mer. 7 janv.",
      "7 janv.", "mer. 7 janv. 1970", "mer. 7 janvier 1970", "mercredi 07/01/1970",
      "mer. 07/01/1970", "mercredi 7 janv. 1970", "7 janvier 1970", "mercredi 7 janvier 1970",
      "7 janv. 1970", "07/01/1970" },
    { "3:00:00 AM", "03:00:00", "03:00:00", "3:00 AM", "03:00", "03:00", "mer 7 gen",
      "7 gen", "mer 7 gen 1970", "mer 7 gennaio 1970", "mercoledì 7/1/1970", "mer 7/1/1970",
      "mercoledì 7 gen 1970", "7 gennaio 1970", "mercoledì 7 gennaio 1970", "7 gen 1970", "07/01/70" },
    { "3:00:00 AM", "03:00:00", "03:00:00", "3:00 AM", "03:00", "03:00", "ოთხ, 7 იან",
      "7 იან", "ოთხ, 7 იან, 1970", "ოთხ, 7 იანვარი, 1970", "ოთხშაბათი, 7.1.1970",
      "ოთხ, 7.1.1970", "ოთხშაბათი, 7 იან, 1970", "7 იანვარი, 1970", "ოთხშაბათი, 7 იანვარი, 1970",
      "7 იან, 1970", "07.01.70" },
    { "3:00:00 AM", "03:00:00", "3:00:00 AM", "3:00 AM", "03:00", "3:00 AM", "बुध, 7 जन",
      "7 जन", "बुध, 7 जन 1970", "बुध, 7 जनवरी 1970", "बुधवार, 7/1/1970", "बुध, 7/1/1970",
      "बुधवार, 7 जन 1970", "7 जनवरी 1970", "बुधवार, 7 जनवरी 1970", "7 जन 1970", "7/1/1970" },
    { "၃:၀၀:၀၀ နံနက်", "၀၃:၀၀:၀၀", "၀၃:၀၀:၀၀", "၃:၀၀ နံနက်", "၀၃:၀၀", "၀၃:၀၀", "ဗုဒ္ဓဟူးနေ့၊ ဇန်နဝါရီလ ၇ ရက်",
      "ဇန်နဝါရီလ ၇ ရက်", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀/၀၁/၀၇", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀/၀၁/၀၇", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "၇၀/၀၁/၀၇" },
    { "3:00:00 ਪੂ.ਦੁ.", "03:00:00", "3:00:00 ਪੂ.ਦੁ.", "3:00 ਪੂ.ਦੁ.", "03:00", "3:00 ਪੂ.ਦੁ.", "ਬੁੱਧ, 7 ਜਨ",
      "7 ਜਨ", "ਬੁੱਧ, 7 ਜਨ 1970", "ਬੁੱਧ, 7 ਜਨਵਰੀ 1970", "ਬੁੱਧਵਾਰ, 7/1/1970", "ਬੁੱਧ, 7/1/1970", "ਬੁੱਧਵਾਰ, 7 ਜਨ 1970",
      "7 ਜਨਵਰੀ 1970", "ਬੁੱਧਵਾਰ, 7 ਜਨਵਰੀ 1970", "7 ਜਨ 1970", "7/1/70" },
    { "3:00:00 AM", "03:00:00", "03:00:00", "3:00 AM", "03:00", "03:00", "qua, 7 de jan", "7 de jan",
      "qua, 7 de jan de 1970", "qua, 7 de janeiro de 1970", "quarta-feira, 07/01/1970", "qua, 07/01/1970",
      "quarta-feira, 7 de jan de 1970", "7 de janeiro de 1970", "quarta-feira, 7 de janeiro de 1970",
      "7 de jan de 1970", "07/01/1970" },
    { "3:00:00 a.m.", "03:00:00", "03:00:00", "3:00 a.m.", "03:00", "03:00", "qua, 7/01", "7 de jan",
      "qua, 7 de jan de 1970", "qua, 7 de janeiro de 1970", "quarta-feira, 07/01/1970", "qua, 07/01/1970",
      "quarta-feira, 7 de jan de 1970", "7 de janeiro de 1970", "quarta-feira, 7 de janeiro de 1970",
      "07/01/1970", "07/01/70" },
    { "3:00:00 пре подне", "03:00:00", "03:00:00", "3:00 пре подне", "03:00", "03:00", "сре 7. јан",
      "7. јан", "сре, 7. јан 1970.", "сре, 7. јануар 1970.", "среда, 7.1.1970.", "сре, 7.1.1970.",
      "среда, 7. јан 1970.", "7. јануар 1970.", "среда, 07. јануар 1970.", "07.01.1970.", "7.1.70." },
    { "3:00:00 ก่อนเที่ยง", "03:00:00", "03:00:00", "3:00 ก่อนเที่ยง", "03:00", "03:00", "พ. 7 ม.ค.",
      "7 ม.ค.", "พ. 7 ม.ค. 1970", "พ. 7 มกราคม  1970", "วันพุธ 7/1/1970", "พ. 7/1/1970",
      "วันพุธที่ 7 ม.ค. 1970", "7 มกราคม  1970", "วันพุธที่ 7 มกราคม  1970", "7 ม.ค. 1970", "7/1/70" },
    { "上午3:00:00", "03:00:00", "上午3:00:00", "上午3:00", "03:00", "上午3:00", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970/1/7周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "1970/1/7" },
    { "上午3:00:00", "03:00:00", "上午3:00:00", "上午3:00", "03:00", "上午3:00", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970/1/7周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "1970/1/7" },
    { "上午3:00:00", "03:00:00", "上午3:00:00", "上午3:00", "03:00", "上午3:00", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "7/1/1970（周三）",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "7/1/70" },
    { "上午3:00:00", "03:00:00", "上午3:00:00", "上午3:00", "03:00", "上午3:00", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970年1月7日，周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "7/1/70" },
    { "上午3:00:00", "03:00:00", "03:00:00", "上午3:00", "03:00", "03:00", "1月7日 週三",
      "1月7日", "1970年1月7日 週三", "1970年1月7日 週三", "1970年1月7日 星期三", "1970/1/7（週三）",
      "1970年1月7日 星期三", "1970年1月7日", "1970年1月7日 星期三", "1970年1月7日", "1970/1/7" }
};

string g_dateTimeFormatNegative[][17] = {
    { "١:١٥:٠٠ ص", "٠١:١٥:٠٠", "١:١٥:٠٠ ص", "١:١٥ ص", "٠١:١٥", "١:١٥ ص", "الأربعاء، ٧ يناير",
      "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "١:١٥:٠٠ ص", "٠١:١٥:٠٠", "١:١٥:٠٠ ص", "١:١٥ ص", "٠١:١٥", "١:١٥ ص", "الأربعاء، ٧ يناير",
      "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "١:١٥:٠٠ ص", "٠١:١٥:٠٠", "١:١٥:٠٠ ص", "١:١٥ ص", "٠١:١٥", "١:١٥ ص", "الأربعاء، ٧ يناير",
      "٧ يناير", "الأربعاء، ٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧/‏١/‏١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠",
      "٧ يناير، ١٩٧٠", "الأربعاء، ٧ يناير، ١٩٧٠", "٠٧‏/٠١‏/١٩٧٠", "٧‏/١‏/١٩٧٠" },
    { "পূৰ্বাহ্ণ ১:১৫:০০", "০১:১৫:০০", "পূৰ্বাহ্ণ ১:১৫:০০", "পূৰ্বাহ্ণ ১:১৫", "০১:১৫",
      "পূৰ্বাহ্ণ ১:১৫", "বুধ, ৭ জানু", "৭ জানু", "বুধ, ৭ জানু ১৯৭০", "বুধ, ৭ জানুৱাৰী, ১৯৭০",
      "বুধবাৰ, ০৭-০১-১৯৭০", "বুধ, ০৭-০১-১৯৭০", "বুধবাৰ, ৭ জানু, ১৯৭০", "৭ জানুৱাৰী, ১৯৭০",
      "বুধবাৰ, ৭ জানুৱাৰী, ১৯৭০", "০৭-০১-১৯৭০", "৭-১-১৯৭০" },
    { "1:15:00 AM", "01:15:00", "01:15:00", "1:15 AM", "01:15", "01:15", "Mi., 7. Jan.",
      "7. Jan.", "Mi., 7. Jan. 1970", "Mi., 7. Januar 1970", "Mittwoch, 7.1.1970", "Mi., 7.1.1970",
      "Mittwoch, 7. Jan. 1970", "7. Januar 1970", "Mittwoch, 7. Januar 1970", "07.01.1970", "07.01.70" },
    { "1:15:00 AM", "01:15:00", "1:15:00 AM", "1:15 AM", "01:15", "1:15 AM", "Wed, Jan 7", "Jan 7",
      "Wed, Jan 7, 1970", "Wed, January 7, 1970", "Wednesday, 1/7/1970", "Wed, 1/7/1970", "Wednesday, Jan 7, 1970",
      "January 7, 1970", "Wednesday, January 7, 1970", "Jan 7, 1970", "1/7/70" },
    { "1:15:00 am", "01:15:00", "01:15:00", "1:15 am", "01:15", "01:15", "Wed, 7 Jan",
      "7 Jan", "Wed, 7 Jan 1970", "Wed, 7 January 1970", "Wednesday, 07/01/1970", "Wed, 07/01/1970",
      "Wednesday, 7 Jan 1970", "7 January 1970", "Wednesday, 7 January 1970", "7 Jan 1970", "07/01/1970" },
    { "1:15:00 am", "01:15:00", "01:15:00", "1:15 am", "01:15", "01:15", "Wed, 7 Jan", "7 Jan",
      "Wed, 7 Jan 1970", "Wed, 7 January 1970", "Wednesday, 07/01/1970", "Wed, 07/01/1970",
      "Wednesday, 7 Jan 1970", "7 January 1970", "Wednesday, 7 January 1970", "7 Jan 1970", "07/01/1970" },
    { "1:15:00 AM", "01:15:00", "1:15:00 AM", "1:15 AM", "01:15", "1:15 AM", "Wed, Jan 7",
      "Jan 7", "Wed, Jan 7, 1970", "Wed, January 7, 1970", "Wednesday, 1/7/1970", "Wed, 1/7/1970",
      "Wednesday, Jan 7, 1970", "January 7, 1970", "Wednesday, January 7, 1970", "Jan 7, 1970", "1/7/70" },
    { "1:15:00 a. m.", "1:15:00", "1:15:00", "1:15 a. m.", "1:15", "1:15", "mié., 7 ene.",
      "7 ene.", "mié., 7 ene. 1970", "mié., 7 de enero de 1970", "miércoles, 7/1/1970",
      "mié., 7/1/1970", "miércoles, 7 de ene. de 1970", "7 de enero de 1970",
      "miércoles, 7 de enero de 1970", "7 ene. 1970", "7/1/70" },
    { "1:15:00 a. m.", "01:15:00", "1:15:00 a. m.", "1:15 a. m.", "01:15", "1:15 a. m.",
      "mié., 7 de ene.", "7 ene.", "mié., 7 de enero de 1970", "mié., 7 de enero de 1970",
      "miércoles, 7/1/1970", "mié., 7/1/1970", "miércoles, 7 de ene. de 1970", "7 de enero de 1970",
      "miércoles, 7 de enero de 1970", "7 ene. 1970", "7/1/1970" },
    { "1:15:00 AM", "01:15:00", "01:15:00", "1:15 AM", "01:15", "01:15", "mer. 7 janv.",
      "7 janv.", "mer. 7 janv. 1970", "mer. 7 janvier 1970", "mercredi 07/01/1970", "mer. 07/01/1970",
      "mercredi 7 janv. 1970", "7 janvier 1970", "mercredi 7 janvier 1970", "7 janv. 1970", "07/01/1970" },
    { "1:15:00 AM", "01:15:00", "01:15:00", "1:15 AM", "01:15", "01:15", "mer 7 gen", "7 gen",
      "mer 7 gen 1970", "mer 7 gennaio 1970", "mercoledì 7/1/1970", "mer 7/1/1970", "mercoledì 7 gen 1970",
      "7 gennaio 1970", "mercoledì 7 gennaio 1970", "7 gen 1970", "07/01/70" },
    { "1:15:00 AM", "01:15:00", "01:15:00", "1:15 AM", "01:15", "01:15", "ოთხ, 7 იან",
      "7 იან", "ოთხ, 7 იან, 1970", "ოთხ, 7 იანვარი, 1970", "ოთხშაბათი, 7.1.1970", "ოთხ, 7.1.1970",
      "ოთხშაბათი, 7 იან, 1970", "7 იანვარი, 1970", "ოთხშაბათი, 7 იანვარი, 1970", "7 იან, 1970", "07.01.70" },
    { "1:15:00 AM", "01:15:00", "1:15:00 AM", "1:15 AM", "01:15", "1:15 AM", "बुध, 7 जन",
      "7 जन", "बुध, 7 जन 1970", "बुध, 7 जनवरी 1970", "बुधवार, 7/1/1970", "बुध, 7/1/1970",
      "बुधवार, 7 जन 1970", "7 जनवरी 1970", "बुधवार, 7 जनवरी 1970", "7 जन 1970", "7/1/1970" },
    { "၁:၁၅:၀၀ နံနက်", "၀၁:၁၅:၀၀", "၀၁:၁၅:၀၀", "၁:၁၅ နံနက်", "၀၁:၁၅", "၀၁:၁၅",
      "ဗုဒ္ဓဟူးနေ့၊ ဇန်နဝါရီလ ၇ ရက်", "ဇန်နဝါရီလ ၇ ရက်", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀/၀၁/၀၇", "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀/၀၁/၀၇",
      "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "ဗုဒ္ဓဟူးနေ့၊ ၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်",
      "၁၉၇၀ ခုနှစ် ဇန်နဝါရီလ ၇ ရက်", "၇၀/၀၁/၀၇" },
    { "1:15:00 ਪੂ.ਦੁ.", "01:15:00", "1:15:00 ਪੂ.ਦੁ.", "1:15 ਪੂ.ਦੁ.", "01:15", "1:15 ਪੂ.ਦੁ.",
      "ਬੁੱਧ, 7 ਜਨ", "7 ਜਨ", "ਬੁੱਧ, 7 ਜਨ 1970", "ਬੁੱਧ, 7 ਜਨਵਰੀ 1970", "ਬੁੱਧਵਾਰ, 7/1/1970",
      "ਬੁੱਧ, 7/1/1970", "ਬੁੱਧਵਾਰ, 7 ਜਨ 1970", "7 ਜਨਵਰੀ 1970", "ਬੁੱਧਵਾਰ, 7 ਜਨਵਰੀ 1970", "7 ਜਨ 1970", "7/1/70" },
    { "1:15:00 AM", "01:15:00", "01:15:00", "1:15 AM", "01:15", "01:15", "qua, 7 de jan",
      "7 de jan", "qua, 7 de jan de 1970", "qua, 7 de janeiro de 1970", "quarta-feira, 07/01/1970",
      "qua, 07/01/1970", "quarta-feira, 7 de jan de 1970", "7 de janeiro de 1970",
      "quarta-feira, 7 de janeiro de 1970", "7 de jan de 1970", "07/01/1970" },
    { "1:15:00 a.m.", "01:15:00", "01:15:00", "1:15 a.m.", "01:15", "01:15", "qua, 7/01",
      "7 de jan", "qua, 7 de jan de 1970", "qua, 7 de janeiro de 1970", "quarta-feira, 07/01/1970",
      "qua, 07/01/1970", "quarta-feira, 7 de jan de 1970", "7 de janeiro de 1970",
      "quarta-feira, 7 de janeiro de 1970", "07/01/1970", "07/01/70" },
    { "1:15:00 пре подне", "01:15:00", "01:15:00", "1:15 пре подне", "01:15", "01:15",
      "сре 7. јан", "7. јан", "сре, 7. јан 1970.", "сре, 7. јануар 1970.", "среда, 7.1.1970.",
      "сре, 7.1.1970.", "среда, 7. јан 1970.", "7. јануар 1970.", "среда, 07. јануар 1970.",
      "07.01.1970.", "7.1.70." },
    { "1:15:00 ก่อนเที่ยง", "01:15:00", "01:15:00", "1:15 ก่อนเที่ยง", "01:15", "01:15", "พ. 7 ม.ค.",
      "7 ม.ค.", "พ. 7 ม.ค. 1970", "พ. 7 มกราคม  1970", "วันพุธ 7/1/1970", "พ. 7/1/1970",
      "วันพุธที่ 7 ม.ค. 1970", "7 มกราคม  1970", "วันพุธที่ 7 มกราคม  1970", "7 ม.ค. 1970", "7/1/70" },
    { "上午1:15:00", "01:15:00", "上午1:15:00", "上午1:15", "01:15", "上午1:15", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970/1/7周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "1970/1/7" },
    { "上午1:15:00", "01:15:00", "上午1:15:00", "上午1:15", "01:15", "上午1:15", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970/1/7周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "1970/1/7" },
    { "上午1:15:00", "01:15:00", "上午1:15:00", "上午1:15", "01:15", "上午1:15", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "7/1/1970（周三）",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "7/1/70" },
    { "上午1:15:00", "01:15:00", "上午1:15:00", "上午1:15", "01:15", "上午1:15", "1月7日周三",
      "1月7日", "1970年1月7日周三", "1970年1月7日周三", "1970年1月7日星期三", "1970年1月7日，周三",
      "1970年1月7日星期三", "1970年1月7日", "1970年1月7日星期三", "1970年1月7日", "7/1/70" },
    { "上午1:15:00", "01:15:00", "01:15:00", "上午1:15", "01:15", "01:15", "1月7日 週三",
      "1月7日", "1970年1月7日 週三", "1970年1月7日 週三", "1970年1月7日 星期三", "1970/1/7（週三）",
      "1970年1月7日 星期三", "1970年1月7日", "1970年1月7日 星期三", "1970年1月7日", "1970/1/7" }
};

string g_formatAbbrDayNames[][7] = {
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "দেও", "সোম", "মঙ্গল", "বুধ", "বৃহ", "শুক্ৰ", "শনি" },
    { "So.", "Mo.", "Di.", "Mi.", "Do.", "Fr.", "Sa." },
    { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" },
    { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" },
    { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" },
    { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" },
    { "dom.", "lun.", "mar.", "mié.", "jue.", "vie.", "sáb." },
    { "dom.", "lun.", "mar.", "mié.", "jue.", "vie.", "sáb." },
    { "dim.", "lun.", "mar.", "mer.", "jeu.", "ven.", "sam." },
    { "dom", "lun", "mar", "mer", "gio", "ven", "sab" },
    { "კვი", "ორშ", "სამ", "ოთხ", "ხუთ", "პარ", "შაბ" },
    { "रवि", "सोम", "मंगल", "बुध", "बृहस्पति", "शुक्र", "शनि" },
    { "တနင်္ဂနွေ", "တနင်္လာ", "အင်္ဂါ", "ဗုဒ္ဓဟူး", "ကြာသပတေး", "သောကြာ", "စနေ" },
    { "ਐਤ", "ਸੋਮ", "ਮੰਗਲ", "ਬੁੱਧ", "ਵੀਰ", "ਸ਼ੁੱਕਰ", "ਸ਼ਨਿੱਚਰ" },
    { "dom", "seg", "ter", "qua", "qui", "sex", "sáb" },
    { "dom", "seg", "ter", "qua", "qui", "sex", "sáb" },
    { "нед", "пон", "уто", "сре", "чет", "пет", "суб" },
    { "อา.", "จ.", "อ.", "พ.", "พฤ.", "ศ.", "ส." },
    { "周日", "周一", "周二", "周三", "周四", "周五", "周六" },
    { "周日", "周一", "周二", "周三", "周四", "周五", "周六" },
    { "周日", "周一", "周二", "周三", "周四", "周五", "周六" },
    { "周日", "周一", "周二", "周三", "周四", "周五", "周六" },
    { "週日", "週一", "週二", "週三", "週四", "週五", "週六" }
};

string g_formatWideDayNames[][7] = {
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "দেওবাৰ", "সোমবাৰ", "মঙ্গলবাৰ", "বুধবাৰ", "বৃহস্পতিবাৰ", "শুক্ৰবাৰ", "শনিবাৰ" },
    { "Sonntag", "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag" },
    { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" },
    { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" },
    { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" },
    { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" },
    { "domingo", "lunes", "martes", "miércoles", "jueves", "viernes", "sábado" },
    { "domingo", "lunes", "martes", "miércoles", "jueves", "viernes", "sábado" },
    { "dimanche", "lundi", "mardi", "mercredi", "jeudi", "vendredi", "samedi" },
    { "domenica", "lunedì", "martedì", "mercoledì", "giovedì", "venerdì", "sabato" },
    { "კვირა", "ორშაბათი", "სამშაბათი", "ოთხშაბათი", "ხუთშაბათი", "პარასკევი", "შაბათი" },
    { "रविवार", "सोमवार", "मंगलवार", "बुधवार", "बृहस्पतिवार", "शुक्रवार", "शनिवार" },
    { "တနင်္ဂနွေ", "တနင်္လာ", "အင်္ဂါ", "ဗုဒ္ဓဟူး", "ကြာသပတေး", "သောကြာ", "စနေ" },
    { "ਐਤਵਾਰ", "ਸੋਮਵਾਰ", "ਮੰਗਲਵਾਰ", "ਬੁੱਧਵਾਰ", "ਵੀਰਵਾਰ", "ਸ਼ੁੱਕਰਵਾਰ", "ਸ਼ਨਿੱਚਰਵਾਰ" },
    { "domingo", "segunda-feira", "terça-feira", "quarta-feira", "quinta-feira", "sexta-feira", "sábado" },
    { "domingo", "segunda-feira", "terça-feira", "quarta-feira", "quinta-feira", "sexta-feira", "sábado" },
    { "недеља", "понедељак", "уторак", "среда", "четвртак", "петак", "субота" },
    { "วันอาทิตย์", "วันจันทร์", "วันอังคาร", "วันพุธ", "วันพฤหัสบดี", "วันศุกร์", "วันเสาร์" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" }
};

string g_standaloneAbbrDayNames[][7] = {
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "দেও", "সোম", "মঙ্গল", "বুধ", "বৃহ", "শুক্ৰ", "শনি" },
    { "So", "Mo", "Di", "Mi", "Do", "Fr", "Sa" },
    { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" },
    { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" },
    { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" },
    { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" },
    { "dom.", "lun.", "mar.", "mié.", "jue.", "vie.", "sáb." },
    { "dom.", "lun.", "mar.", "mié.", "jue.", "vie.", "sáb." },
    { "dim.", "lun.", "mar.", "mer.", "jeu.", "ven.", "sam." },
    { "dom", "lun", "mar", "mer", "gio", "ven", "sab" },
    { "კვი", "ორშ", "სამ", "ოთხ", "ხუთ", "პარ", "შაბ" },
    { "रवि", "सोम", "मंगल", "बुध", "बृहस्पति", "शुक्र", "शनि" },
    { "တနင်္ဂနွေ", "တနင်္လာ", "အင်္ဂါ", "ဗုဒ္ဓဟူး", "ကြာသပတေး", "သောကြာ", "စနေ" },
    { "ਐਤ", "ਸੋਮ", "ਮੰਗਲ", "ਬੁੱਧ", "ਵੀਰ", "ਸ਼ੁੱਕਰ", "ਸ਼ਨਿੱਚਰ" },
    { "dom", "seg", "ter", "qua", "qui", "sex", "sáb" },
    { "dom", "seg", "ter", "qua", "qui", "sex", "sáb" },
    { "нед", "пон", "уто", "сре", "чет", "пет", "суб" },
    { "อา.", "จ.", "อ.", "พ.", "พฤ.", "ศ.", "ส." },
    { "周日", "周一", "周二", "周三", "周四", "周五", "周六" },
    { "周日", "周一", "周二", "周三", "周四", "周五", "周六" },
    { "周日", "周一", "周二", "周三", "周四", "周五", "周六" },
    { "周日", "周一", "周二", "周三", "周四", "周五", "周六" },
    { "週日", "週一", "週二", "週三", "週四", "週五", "週六" }
};

string g_standaloneWideDayNames[][7] = {
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "الأحد", "الاثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت" },
    { "দেওবাৰ", "সোমবাৰ", "মঙ্গলবাৰ", "বুধবাৰ", "বৃহস্পতিবাৰ", "শুক্ৰবাৰ", "শনিবাৰ" },
    { "Sonntag", "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag" },
    { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" },
    { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" },
    { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" },
    { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" },
    { "domingo", "lunes", "martes", "miércoles", "jueves", "viernes", "sábado" },
    { "domingo", "lunes", "martes", "miércoles", "jueves", "viernes", "sábado" },
    { "dimanche", "lundi", "mardi", "mercredi", "jeudi", "vendredi", "samedi" },
    { "domenica", "lunedì", "martedì", "mercoledì", "giovedì", "venerdì", "sabato" },
    { "კვირა", "ორშაბათი", "სამშაბათი", "ოთხშაბათი", "ხუთშაბათი", "პარასკევი", "შაბათი" },
    { "रविवार", "सोमवार", "मंगलवार", "बुधवार", "बृहस्पतिवार", "शुक्रवार", "शनिवार" },
    { "တနင်္ဂနွေ", "တနင်္လာ", "အင်္ဂါ", "ဗုဒ္ဓဟူး", "ကြာသပတေး", "သောကြာ", "စနေ" },
    { "ਐਤਵਾਰ", "ਸੋਮਵਾਰ", "ਮੰਗਲਵਾਰ", "ਬੁੱਧਵਾਰ", "ਵੀਰਵਾਰ", "ਸ਼ੁੱਕਰਵਾਰ", "ਸ਼ਨਿੱਚਰਵਾਰ" },
    { "domingo", "segunda-feira", "terça-feira", "quarta-feira", "quinta-feira", "sexta-feira", "sábado" },
    { "domingo", "segunda-feira", "terça-feira", "quarta-feira", "quinta-feira", "sexta-feira", "sábado" },
    { "недеља", "понедељак", "уторак", "среда", "четвртак", "петак", "субота" },
    { "วันอาทิตย์", "วันจันทร์", "วันอังคาร", "วันพุธ", "วันพฤหัสบดี", "วันศุกร์", "วันเสาร์" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" },
    { "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" }
};

string g_formatAbbrMonthNames[][12] = {
    { "يناير", "فبراير", "مارس", "أبريل",
      "مايو", "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "يناير", "فبراير", "مارس", "أبريل",
      "مايو", "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "يناير", "فبراير", "مارس", "أبريل",
      "مايو", "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "জানু", "ফেব্ৰু", "মাৰ্চ", "এপ্ৰিল", "মে", "জুন", "জুলাই", "আগ", "সেপ্ট", "অক্টো", "নভে", "ডিসে" },
    { "Jan.", "Feb.", "März", "Apr.", "Mai", "Juni", "Juli", "Aug.", "Sept.", "Okt.", "Nov.", "Dez." },
    { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" },
    { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" },
    { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" },
    { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" },
    { "ene.", "feb.", "mar.", "abr.", "may.", "jun.", "jul.", "ago.", "sept.", "oct.", "nov.", "dic." },
    { "ene.", "feb.", "mar.", "abr.", "may.", "jun.", "jul.", "ago.", "sep.", "oct.", "nov.", "dic." },
    { "janv.", "févr.", "mars", "avr.", "mai", "juin", "juil.", "août", "sept.", "oct.", "nov.", "déc." },
    { "gen", "feb", "mar", "apr", "mag", "giu", "lug", "ago", "set", "ott", "nov", "dic" },
    { "იან", "თებ", "მარ", "აპრ", "მაი", "ივნ", "ივლ", "აგვ", "სექ", "ოქტ", "ნოე", "დეკ" },
    { "जन", "फर", "मा", "अप्रै", "म", "जू", "जु", "अग", "सितं", "अक्टू", "नवं", "दिसं" },
    { "ဇန်နဝါရီ", "ဖေဖော်ဝါရီ", "မတ်", "ဧပြီ", "မေ", "ဇွန်", "ဇူလိုင်", "ဩဂုတ်", "စက်တင်ဘာ",
      "အောက်တိုဘာ", "နိုဝင်ဘာ", "ဒီဇင်ဘာ" },
    { "ਜਨ", "ਫ਼ਰ", "ਮਾਰਚ", "ਅਪ੍ਰੈ", "ਮਈ", "ਜੂਨ", "ਜੁਲਾ", "ਅਗ", "ਸਤੰ", "ਅਕਤੂ", "ਨਵੰ", "ਦਸੰ" },
    { "jan", "fev", "mar", "abr", "mai", "jun", "jul", "ago", "set", "out", "nov", "dez" },
    { "jan", "fev", "mar", "abr", "mai", "jun", "jul", "ago", "set", "out", "nov", "dez" },
    { "јан", "феб", "мар", "апр", "мај", "јун", "јул", "авг", "сеп", "окт", "нов", "дец" },
    { "ม.ค.", "ก.พ.", "มี.ค.", "เม.ย.", "พ.ค.", "มิ.ย.", "ก.ค.", "ส.ค.", "ก.ย.", "ต.ค.", "พ.ย.", "ธ.ค." },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" }
};

string g_formatWideMonthNames[][12] = {
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "জানুৱাৰী", "ফেব্ৰুৱাৰী", "মাৰ্চ", "এপ্ৰিল", "মে", "জুন", "জুলাই", "আগষ্ট",
      "ছেপ্তেম্বৰ", "অক্টোবৰ", "নৱেম্বৰ", "ডিচেম্বৰ" },
    { "Januar", "Februar", "März", "April", "Mai", "Juni", "Juli", "August",
      "September", "Oktober", "November", "Dezember" },
    { "January", "February", "March", "April", "May", "June", "July", "August",
      "September", "October", "November", "December" },
    { "January", "February", "March", "April", "May", "June", "July", "August",
      "September", "October", "November", "December" },
    { "January", "February", "March", "April", "May", "June", "July", "August",
      "September", "October", "November", "December" },
    { "January", "February", "March", "April", "May", "June", "July", "August",
      "September", "October", "November", "December" },
    { "enero", "febrero", "marzo", "abril", "mayo", "junio", "julio", "agosto",
      "septiembre", "octubre", "noviembre", "diciembre" },
    { "enero", "febrero", "marzo", "abril", "mayo", "junio", "julio", "agosto",
      "septiembre", "octubre", "noviembre", "diciembre" },
    { "janvier", "février", "mars", "avril", "mai", "juin", "juillet", "août",
      "septembre", "octobre", "novembre", "décembre" },
    { "gennaio", "febbraio", "marzo", "aprile", "maggio", "giugno", "luglio",
      "agosto", "settembre", "ottobre", "novembre", "dicembre" },
    { "იანვარი", "თებერვალი", "მარტი", "აპრილი", "მაისი", "ივნისი", "ივლისი",
      "აგვისტო", "სექტემბერი", "ოქტომბერი", "ნოემბერი", "დეკემბერი" },
    { "जनवरी", "फरवरी", "मार्च", "अप्रैल", "मई", "जून", "जुलाई", "अगस्त", "सितम्बर",
      "अक्तूबर", "नवंबर", "दिसंबर" },
    { "ဇန်နဝါရီ", "ဖေဖော်ဝါရီ", "မတ်", "ဧပြီ", "မေ", "ဇွန်", "ဇူလိုင်", "ဩဂုတ်",
      "စက်တင်ဘာ", "အောက်တိုဘာ", "နိုဝင်ဘာ", "ဒီဇင်ဘာ" },
    { "ਜਨਵਰੀ", "ਫ਼ਰਵਰੀ", "ਮਾਰਚ", "ਅਪ੍ਰੈਲ", "ਮਈ", "ਜੂਨ", "ਜੁਲਾਈ", "ਅਗਸਤ",
      "ਸਤੰਬਰ", "ਅਕਤੂਬਰ", "ਨਵੰਬਰ", "ਦਸੰਬਰ" },
    { "janeiro", "fevereiro", "março", "abril", "maio", "junho", "julho",
      "agosto", "setembro", "outubro", "novembro", "dezembro" },
    { "janeiro", "fevereiro", "março", "abril", "maio", "junho", "julho",
      "agosto", "setembro", "outubro", "novembro", "dezembro" },
    { "јануар", "фебруар", "март", "април", "мај", "јун", "јул", "август",
      "септембар", "октобар", "новембар", "децембар" },
    { "มกราคม", "กุมภาพันธ์", "มีนาคม", "เมษายน", "พฤษภาคม", "มิถุนายน", "กรกฎาคม",
      "สิงหาคม", "กันยายน", "ตุลาคม", "พฤศจิกายน", "ธันวาคม" },
    { "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" },
    { "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" },
    { "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" },
    { "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" }
};

string g_standaloneAbbrMonthNames[][12] = {
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "জানু", "ফেব্ৰু", "মাৰ্চ", "এপ্ৰিল", "মে’", "জুন", "জুলাই", "আগ", "ছেপ্তে", "অক্টো", "নৱে", "ডিচে" },
    { "Jan", "Feb", "Mär", "Apr", "Mai", "Jun", "Jul", "Aug", "Sep", "Okt", "Nov", "Dez" },
    { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" },
    { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" },
    { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" },
    { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" },
    { "ene.", "feb.", "mar.", "abr.", "may.", "jun.", "jul.", "ago.", "sept.", "oct.", "nov.", "dic." },
    { "ene.", "feb.", "mar.", "abr.", "may.", "jun.", "jul.", "ago.", "sep.", "oct.", "nov.", "dic." },
    { "janv.", "févr.", "mars", "avr.", "mai", "juin", "juil.", "août", "sept.", "oct.", "nov.", "déc." },
    { "gen", "feb", "mar", "apr", "mag", "giu", "lug", "ago", "set", "ott", "nov", "dic" },
    { "იან", "თებ", "მარ", "აპრ", "მაი", "ივნ", "ივლ", "აგვ", "სექ", "ოქტ", "ნოე", "დეკ" },
    { "जन॰", "फ़र॰", "मार्च", "अप्रैल", "मई", "जून", "जुल॰", "अग॰", "सित॰", "अक्तू॰", "नव॰", "दिस॰" },
    { "ဇန်နဝါရီ", "ဖေဖော်ဝါရီ", "မတ်", "ဧပြီ", "မေ", "ဇွန်", "ဇူလိုင်", "ဩဂုတ်",
      "စက်တင်ဘာ", "အောက်တိုဘာ", "နိုဝင်ဘာ", "ဒီဇင်ဘာ" },
    { "ਜਨ", "ਫ਼ਰ", "ਮਾਰਚ", "ਅਪ੍ਰੈ", "ਮਈ", "ਜੂਨ", "ਜੁਲਾ", "ਅਗ", "ਸਤੰ", "ਅਕਤੂ", "ਨਵੰ", "ਦਸੰ" },
    { "jan", "fev", "mar", "abr", "mai", "jun", "jul", "ago", "set", "out", "nov", "dez" },
    { "jan", "fev", "mar", "abr", "mai", "jun", "jul", "ago", "set", "out", "nov", "dez" },
    { "јан", "феб", "мар", "апр", "мај", "јун", "јул", "авг", "сеп", "окт", "нов", "дец" },
    { "ม.ค.", "ก.พ.", "มี.ค.", "เม.ย.", "พ.ค.", "มิ.ย.", "ก.ค.", "ส.ค.", "ก.ย.", "ต.ค.", "พ.ย.", "ธ.ค." },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" }
};

string g_standaloneWideMonthNames[][12] = {
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "يناير", "فبراير", "مارس", "أبريل", "مايو",
      "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" },
    { "জানুৱাৰী", "ফেব্ৰুৱাৰী", "মাৰ্চ", "এপ্ৰিল", "মে’", "জুন", "জুলাই", "আগষ্ট",
      "ছেপ্তেম্বৰ", "অক্টোবৰ", "নৱেম্বৰ", "ডিচেম্বৰ" },
    { "Januar", "Februar", "März", "April", "Mai", "Juni", "Juli", "August",
      "September", "Oktober", "November", "Dezember" },
    { "January", "February", "March", "April", "May", "June", "July", "August",
      "September", "October", "November", "December" },
    { "January", "February", "March", "April", "May", "June", "July", "August",
      "September", "October", "November", "December" },
    { "January", "February", "March", "April", "May", "June", "July", "August",
      "September", "October", "November", "December" },
    { "January", "February", "March", "April", "May", "June", "July", "August",
      "September", "October", "November", "December" },
    { "enero", "febrero", "marzo", "abril", "mayo", "junio", "julio", "agosto",
      "septiembre", "octubre", "noviembre", "diciembre" },
    { "enero", "febrero", "marzo", "abril", "mayo", "junio", "julio", "agosto",
      "septiembre", "octubre", "noviembre", "diciembre" },
    { "janvier", "février", "mars", "avril", "mai", "juin", "juillet", "août",
      "septembre", "octobre", "novembre", "décembre" },
    { "gennaio", "febbraio", "marzo", "aprile", "maggio", "giugno", "luglio",
      "agosto", "settembre", "ottobre", "novembre", "dicembre" },
    { "იანვარი", "თებერვალი", "მარტი", "აპრილი", "მაისი", "ივნისი", "ივლისი",
      "აგვისტო", "სექტემბერი", "ოქტომბერი", "ნოემბერი", "დეკემბერი" },
    { "जनवरी", "फरवरी", "मार्च", "अप्रैल", "मई", "जून", "जुलाई", "अगस्त", "सितम्बर",
      "अक्तूबर", "नवंबर", "दिसंबर" },
    { "ဇန်နဝါရီ", "ဖေဖော်ဝါရီ", "မတ်", "ဧပြီ", "မေ", "ဇွန်", "ဇူလိုင်", "ဩဂုတ်",
      "စက်တင်ဘာ", "အောက်တိုဘာ", "နိုဝင်ဘာ", "ဒီဇင်ဘာ" },
    { "ਜਨਵਰੀ", "ਫ਼ਰਵਰੀ", "ਮਾਰਚ", "ਅਪ੍ਰੈਲ", "ਮਈ", "ਜੂਨ", "ਜੁਲਾਈ", "ਅਗਸਤ",
      "ਸਤੰਬਰ", "ਅਕਤੂਬਰ", "ਨਵੰਬਰ", "ਦਸੰਬਰ" },
    { "janeiro", "fevereiro", "março", "abril", "maio", "junho", "julho",
      "agosto", "setembro", "outubro", "novembro", "dezembro" },
    { "janeiro", "fevereiro", "março", "abril", "maio", "junho", "julho",
      "agosto", "setembro", "outubro", "novembro", "dezembro" },
    { "јануар", "фебруар", "март", "април", "мај", "јун", "јул", "август",
      "септембар", "октобар", "новембар", "децембар" },
    { "มกราคม", "กุมภาพันธ์", "มีนาคม", "เมษายน", "พฤษภาคม", "มิถุนายน", "กรกฎาคม",
      "สิงหาคม", "กันยายน", "ตุลาคม", "พฤศจิกายน", "ธันวาคม" },
    { "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" },
    { "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" },
    { "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" },
    { "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" },
    { "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" }
};

string g_amPmMarkers[][2] = {
    { "ص", "م" },
    { "ص", "م" },
    { "ص", "م" },
    { "পূৰ্বাহ্ণ", "অপৰাহ্ণ" },
    { "AM", "PM" },
    { "AM", "PM" },
    { "am", "pm" },
    { "am", "pm" },
    { "AM", "PM" },
    { "a. m.", "p. m." },
    { "a. m.", "p. m." },
    { "AM", "PM" },
    { "AM", "PM" },
    { "AM", "PM" },
    { "AM", "PM" },
    { "နံနက်", "ညနေ" },
    { "ਪੂ.ਦੁ.", "ਬਾ.ਦੁ." },
    { "AM", "PM" },
    { "a.m.", "p.m." },
    { "пре подне", "по подне" },
    { "ก่อนเที่ยง", "หลังเที่ยง" },
    { "上午", "下午" },
    { "上午", "下午" },
    { "上午", "下午" },
    { "上午", "下午" },
    { "上午", "下午" }
};
} // namespace testing

#endif // UNIT_DATETIME_TEST_H_
